==> diamond-shop-v1.3.50-043668.zip: src/Services/Sms.php <==
<?

namespace Shop\Services;

use SmsSender\Exceptions\SmsException;

/**
 * Description of Sms
 *
 * @author Admin
 */
class Sms
{

    protected $smsConf;
    
    protected $smsLogRepo;

    function __construct(\Shop\Config\Sms $smsConf, \Shop\Repositories\SmsLog $smsLogRepo)
    {
        $this->confSms = $smsConf;
        $this->smsLogRepo = $smsLogRepo;
    }

    /**
     * 
     * @return \SmsSender\Sender
     */
    private function build()
    {
        $config = new \SmsSender\Drivers\Smsc\Config;
        $config
                ->setLogin($this->confSms->getLogin())
                ->setPassword($this->confSms->getPassword())
                ->setFrom($this->confSms->getFrom())
        ;

        return new \SmsSender\Sender(new \SmsSender\Drivers\Smsc\Smsc($config));
    }

    /**
     * 
     * @param type $phone
     * @param \Diamond\DTO\Message $message
     * @return int
     * @throws \Shop\Exceptions\NotifySendError
     * @throws \Shop\Exceptions\NotifySend
     * @throws \Exception
     */
    public function sendSms($phone, \Diamond\DTO\Message $message): int
    {

        if ($this->confSms->getDebug() == "sendToSmsDISSABLED") {
            return 0;
        }

        if ($this->confSms->getDebug() == "DEBUG_PHONE" && $this->confSms->getDebugPhone() > "") {
            $phone = $this->confSms->getDebugPhone();
        } elseif ($this->confSms->getDebug() == "DEBUG_PHONE") {
            throw new \Shop\Exceptions\NotifySendError("Номер для отладки смс сообщений не задан.");
        }

        if ($this->confSms->getDebug() == "DEBUG_DISPLAY") {
            throw new \Shop\Exceptions\NotifySend('Отправка смс на номер ' . $phone . ' Текст: ' . $message->getContent());
        }

        if ( ! $this->confSms->getLogin() || ! $this->confSms->getPassword()) {
            throw new \Shop\Exceptions\NotifySendError("Логин или пароль от сервиса смс сообщений не заданны.");
        }



        try {
            
            $smsSender = $this->build();

            $result = $smsSender->send($phone, $message->getContent());

            $this->smsLogRepo
                    ->buildEntity()
                    ->setPhone($phone)
                    ->setStatus($result->getMessage())
                    ->setContent($message->getContent())
                    ->save()
            ;
        }
        catch (SmsException $ex) {

            $this->smsLogRepo
                    ->buildEntity()
                    ->setPhone($phone)
                    ->setStatus($ex->getMessage())
                    ->setContent($message->getContent())
                    ->save();

            throw new \Shop\Exceptions\NotifySendError("При отправке возникла непредвиденная ошибка");
        }

        return $result->getId();
    }

    /**
     * Получение баланса
     * @return int
     */
    public function getBalance():int
    {

        if ($this->confSms->getDebug() == "sendToSmsDISSABLED") {
            return 0;
        }        
        
        $smsSender = $this->build();
        
        
        return $smsSender->getBalance();
    }

}

==> diamond-shop-v1.4.14-99a1b7.zip: src/Services/Sms.php <==
<?

namespace Shop\Services;

use SmsSender\Exceptions\SmsException;

/**
 * Description of Sms
 *
 * @author Admin
 */
class Sms
{

    protected $smsConf;
    
    protected $smsLogRepo;

    function __construct(\Shop\Config\Sms $smsConf, \Shop\Repositories\SmsLog $smsLogRepo)
    {
        $this->confSms = $smsConf;
        $this->smsLogRepo = $smsLogRepo;
    }

    /**
     * 
     * @return \SmsSender\Sender
     */
    private function build()
    {
        $config = new \SmsSender\Drivers\Smsc\Config;
        $config
                ->setLogin($this->confSms->getLogin())
                ->setPassword($this->confSms->getPassword())
                ->setFrom($this->confSms->getFrom())
        ;

        return new \SmsSender\Sender(new \SmsSender\Drivers\Smsc\Smsc($config));
    }

    /**
     * 
     * @param type $phone
     * @param \Diamond\DTO\Message $message
     * @return int
     * @throws \Shop\Exceptions\NotifySendError
     * @throws \Shop\Exceptions\NotifySend
     * @throws \Exception
     */
    public function sendSms($phone, \Diamond\DTO\Message $message): int
    {

        if ($this->confSms->getDebug() == "sendToSmsDISSABLED") {
            return 0;
        }

        if ($this->confSms->getDebug() == "DEBUG_PHONE" && $this->confSms->getDebugPhone() > "") {
            $phone = $this->confSms->getDebugPhone();
        } elseif ($this->confSms->getDebug() == "DEBUG_PHONE") {
            throw new \Shop\Exceptions\NotifySendError("Номер для отладки смс сообщений не задан.");
        }

        if ($this->confSms->getDebug() == "DEBUG_DISPLAY") {
            throw new \Shop\Exceptions\NotifySend('Отправка смс на номер ' . $phone . ' Текст: ' . $message->getContent());
        }

        if ( ! $this->confSms->getLogin() || ! $this->confSms->getPassword()) {
            throw new \Shop\Exceptions\NotifySendError("Логин или пароль от сервиса смс сообщений не заданны.");
        }



        try {
            
            $smsSender = $this->build();

            $result = $smsSender->send($phone, $message->getContent());

            $this->smsLogRepo
                    ->buildEntity()
                    ->setPhone($phone)
                    ->setStatus($result->getMessage())
                    ->setContent($message->getContent())
                    ->save()
            ;
        }
        catch (SmsException $ex) {

            $this->smsLogRepo
                    ->buildEntity()
                    ->setPhone($phone)
                    ->setStatus($ex->getMessage())
                    ->setContent($message->getContent())
                    ->save();

            throw new \Shop\Exceptions\NotifySendError("При отправке возникла непредвиденная ошибка: " . $ex->getMessage());
        }

        return $result->getId();
    }

    /**
     * Получение баланса
     * @return int
     */
    public function getBalance():int
    {

        if ($this->confSms->getDebug() == "sendToSmsDISSABLED") {
            return 0;
        }        
        
        $smsSender = $this->build();
        
        
        return $smsSender->getBalance();
    }

}
